#
# spec file for package vte2
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _sover 9
%define _apiver 0.0
# empty:
#%%define _binver
%define _gtkver 2.0
%define _name   vte
Name:           vte2
Version:        0.28.2
Release:        lp152.4.6
Summary:        Terminal Emulator Library
License:        GPL-2.0-or-later
Group:          Development/Libraries/GNOME
Url:            http://www.gnome.org
Source:         http://download.gnome.org/sources/vte/0.28/%{_name}-%{version}.tar.bz2
# PATCH-FIX-UPSTREAM vte-keymaps.patch bnc#754350 bgo#663779 dimstar@opensuse.org -- keymap: Treat ALT as META. Patch from tracker, comment 38. So far the likeliest candidate to be merged.
Patch0:         vte-keymaps.patch
# PATCH-FIX-UPSTREAM vte-CVE-2012-2738.patch bnc#772761 bgo#676090 CVE-2012-2738 vuntz@opensuse.org -- malicious escape sequences can cause denial of service, taken from git
Patch1:         vte-CVE-2012-2738.patch
# PATCH-FIX-UPSTREAM vte-0.28.2-paste-fix.patch bgo#729533 rh#1114301 develop7@develop7.info -- Bracketed paste should be per-terminal, not per screen
Patch2:         vte-0.28.2-paste-fix.patch
BuildRequires:  fdupes
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk2-devel
BuildRequires:  intltool
BuildRequires:  ncurses-devel
BuildRequires:  python-devel
BuildRequires:  python-gtk-devel
BuildRequires:  translation-update-upstream

%description
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

%package -n libvte%{_sover}
Summary:        Terminal Emulator Library
Group:          System/Libraries
Recommends:     %{name}-lang
# Needed to make lang package installable (and because we used to
# have a vte package earlier).
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}

%description -n libvte%{_sover}
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

%package -n gnome-pty-helper
Summary:        Helper for utmp/wtmp/lastlog logging
# FIXME: use proper Requires(pre/post/preun/...)
# FIXME: use proper Requires(pre/post/preun/...)
Group:          System/Libraries
PreReq:         permissions

%description -n gnome-pty-helper
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

This package provides a helper for utmp/wtmp/lastlog logging.

%package tools
Summary:        Tools from the VTE terminal emulator library
Group:          System/Libraries

%description tools
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

This package provides tools using VTE.

%package -n python-vte
Summary:        Python bindings for the VTE terminal emulator library
Group:          System/Libraries
Requires:       libvte9 = %{version}

%description -n python-vte
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

This package provides the python bindings for VTE.

%package devel
Summary:        Development files for the VTE terminal emulator library
Group:          Development/Libraries/GNOME
Requires:       libvte%{_sover} = %{version}
Provides:       vte-doc = %{version}
Obsoletes:      glade3-catalog-vte
Obsoletes:      vte-doc < %{version}

%description devel
VTE is a terminal emulator library that provides a terminal widget for
use with GTK+ as well as handling of child process and terminal
emulation settings.

This package contains the files needed for building applications using
VTE.

%lang_package

%prep
%setup -q -n %{_name}-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1
translation-update-upstream

%build
%configure --with-gtk=%{_gtkver}\
        --disable-static \
        --disable-introspection
make %{?_smp_mflags} V=1

%install
%make_install
%if 0%{?suse_version} <= 1120
rm %{buildroot}%{_datadir}/locale/en@shaw/LC_MESSAGES/*
%endif
# Files that will come with gtk3 build
rm %{buildroot}%{_libexecdir}/gnome-pty-helper
%find_lang vte-%{_apiver}
find %{buildroot} -type f -name "*.la" -delete -print
%fdupes %{buildroot}

%post -n libvte%{_sover} -p /sbin/ldconfig
%postun -n libvte%{_sover} -p /sbin/ldconfig

%files -n libvte%{_sover}
%license COPYING
%doc AUTHORS README NEWS ChangeLog
%{_libdir}/*.so.*
%dir %{_datadir}/vte
%dir %{_datadir}/vte/termcap-%{_apiver}
%{_datadir}/vte/termcap-%{_apiver}/xterm

%files tools
%{_bindir}/vte%{?_binver}

%files -n python-vte
%doc python/vte-demo.py
%{py_sitedir}/gtk-2.0/*.so

%files devel
%{_libdir}/pkgconfig/*.pc
%{_libdir}/*.so
%{_includedir}/vte-%{_apiver}/
%dir %{_datadir}/pygtk
%dir %{_datadir}/pygtk/2.0
%dir %{_datadir}/pygtk/2.0/defs
%{_datadir}/pygtk/2.0/defs/vte.defs
# Own these repositories to not depend on gtk-doc while building:
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%{_datadir}/gtk-doc/html/vte-%{_apiver}/

%files lang -f vte-%{_apiver}.lang

%changelog
* Mon Mar  5 2018 jengelh@inai.de
- Fix SRPM group. Update summaries.
* Mon Feb 26 2018 dimstar@opensuse.org
- Use SPDX3.0 license tags and package COPYING as %%license.
- Modernize spec file using spec-cleaner.
* Wed May 31 2017 zaitor@opensuse.org
- Drop libgladeui-1_0-devel BuildRequires and stop passing
  - -enable-glade-catalogue to configure, no longer build glade
  integration.
- Following the above, drop glade3-catalog-vte subpackage and
  obsolete it from develpackage to ensure it will be removed from
  users systems.
* Wed Sep 14 2016 develop7@develop7.info
- add vte-0.28.2-paste-fix.patch: fixes adding extra characters
  when pasting to terminal (rh#1114301 bgo#729533 deb#734571).
* Fri May 27 2016 idonmez@suse.com
- Update to GNOME 3.20.2 FATE#318572
- Fixes bsc#979317
* Wed Sep 23 2015 dimstar@opensuse.org
- Drop gnome-pty-helper requires: this script is no longer used
  in GNOME 3.18.0.
* Fri Jul 19 2013 dimstar@opensuse.org
- No longer provide introspection support for Vte 0.0 (nothing
  really depends on it, most packages expect Vte 2.90 typelibs):
  + Pass --disable-introspection to configure instead of
  - -enable-introspection.
  + Drop typelib-1_0-Vte-0_0 subpackage and no longer require it
    from the -devel package.
* Tue Nov  6 2012 dimstar@opensuse.org
- Fix typo in tag line of vte-CVE-2012-2738.patch.
* Wed Jul 25 2012 vuntz@opensuse.org
- Add vte-CVE-2012-2738.patch: fix potential DoS through malicious
  escape sequences. Fix bnc#772761, CVE-2012-2738.
* Thu May 17 2012 dimstar@opensuse.org
- Add vte-keymaps.patch: keymap: Treat ALT as META. [bnc#754350,
  bgo#663779].
* Thu Dec  8 2011 dimstar@opensuse.org
- Split typelib file into typelib-1_0-Vte-0_0 subpackage.
- Add typelib-1_0-Vte-0_0 Requires to devel subpackage.
* Fri Sep  2 2011 vuntz@opensuse.org
- Update to version 0.28.2:
  + Dist correct gtk-doc API docs
  + Updated translations.
* Fri Sep  2 2011 vuntz@opensuse.org
- Remove support from vte source package, since new versions of
  vte are GTK+ 3 only, and so we need to keep this old version just
  for GTK+ 2.
- Remove build_for_gtk2 and build_glade_catalog macros, and keep
  things as they were both set to 1.
* Wed Jun 15 2011 vuntz@opensuse.org
- Update to version 0.28.1:
  + bgo#652124: malicious escape sequence causes gnome-terminal to
    exhaust memory
  + Updated translations.
* Wed May 18 2011 vuntz@opensuse.org
- Drop rpmlintrc as the new path for gnome-pty-helper is now known
  by the permissions system.
* Thu May  5 2011 vuntz@opensuse.org
- Use %%set_permissions instead of deprecated %%run_permissions in
  %%post of gnome-pty-helper.
- Move %%verify_permissions to %%verifyscript of gnome-pty-helper.
- Only put gnome-pty-helper scriptlets if %%{build_for_gtk2} is not
  set, since we don't build gnome-pty-helper when building for
  gtk2.
* Wed Apr 27 2011 vuntz@opensuse.org
- Split gnome-pty-helper in its own package, and stop installing it
  in a non-default libexecdir: it is needed by both gtk2 and gtk3
  versions of vte, and we don't want to have it twice. So only keep
  the one we get with the gtk3 build.
- Add Requires for gnome-pty-helper to libvte9 and libvte2_90.
- Update rpmlintrc accordingly.
* Mon Apr  4 2011 fcrozat@novell.com
- Update to version 0.28.0:
  + bgo#642184: vte does not build against new glade (with
    gladeui-2.0).
  + Updated translations.
- Changes with version 0.27.90:
  + Remove gsettings .enums.xml.
  + Fix shrinking terminal on gtk3
  + Updated translations.
- Changes with version 0.27.5:
  + Fix build with recent GTK+
  + Updated translations.
- Changes with version 0.27.4:
  + Fix build with recent GTK+
  + Introspection fixes for fork_command_full
  + Updated translations.
- Changes with version 0.27.3:
  + Add a gsettings .enums.xml file for vte's enum types
  + Fix build with latest gtk 3
  + Fix introspection annotations and require gobject-introspection 0.9.0
  + Bugs fixed: bgo#628870.
  + Updated translations.
- Changes with version 0.27.2:
  + GTK+ 3 fixes.
  + Updated translations.
- Changes with version 0.27.1:
  + Bugs fixed:
  - bgo#631589: Pass the correct TERM value inside envp when
    spawning
  - bgo#631903: Report correct minimum/natural sizes for GTK+ 3
  - bgo#632257: vte leaks FDs
  + Updated translations.
- Add pre_checkin.sh to build gtk2 and gtk3 version of the package
  and add some macros to handle dual gtk2 / gtk3 packages.
- Differences between gtk2 / gtk3 packages:
  + Pass --with-gtk=2.0/--with-gtk=3.0 to configure as appropriate.
  + python-vte is only built for gtk2, as introspection is used for
    gtk3.
- Disable glade catalogue build for gtk3 with build_glade_catalog
  macro, as we don't have a gtk3-powered glade right now.
- Remove %%py_requires from main package since we don't build a vte
  binary package.
- Add rpmlintrc files to avoid a permissions-file-setuid-bit error
  that makes the build fail. Security team will review that
  (bnc#690202).
* Tue Nov 16 2010 dimstar@opensuse.org
- Update to version 0.26.2:
  + bgo#632257: Plug FD leak.
* Tue Nov 16 2010 aj@suse.de
- Use group utmp for gnome-pty-helper (bnc#652877).
* Wed Oct 13 2010 vuntz@opensuse.org
- Update to version 0.26.1:
  + Pass the correct TERM value inside envp when spawning.
  + bgo#631589: set_emulation does not work in the python bindings
* Tue Oct  5 2010 vuntz@opensuse.org
- Split vte according to the shared library policy (bnc#634199):
  + create libvte9, vte-tools, python-vte, glade3-catalog-vte
    subpackages.
  + add Provides/Obsoletes for vte to libvte9, for migration and
    for the lang package
  + use Recommends for the lang package in libvte9
  + add glade3 Requires to glade3-catalog-vte, as well as a
    Supplements for packageand(glade3:vte-devel) for automatic
    installation for people who are developing with VTE.
  + use {_libexecdir}/libvte9 as libexecdir, to potentially have
    multiple versions of gnome-pty-helper parallel-installable (the
    protocol used between the helper and vte could change).
- The glade3-catalog-vte subpackage is part of bnc#637694.
- Remove explicit Requires of devel packages in vte-devel: they
  will be added automatically the pkgconfig() way.
- Update summaries and descriptions.
* Mon Sep 27 2010 vuntz@opensuse.org
- Update to version 0.26.0:
  + Clarify TERM env var handling with VtePty.
  + Build fixes.
  + Updated translations.
* Sun Aug 29 2010 dimstar@opensuse.org
- Update to version 0.25.91:
  + bgo#627764: mismanaged GtkStyle lifecycle
  + bgo#601926: Don't hardcode meta to alt
  + Various build fixes.
  + Updated translations
* Tue Aug 24 2010 vuntz@opensuse.org
- Add gobject-introspection-devel BuildRequires and pass
  - -enable-introspection to configure to build introspection
  support.
* Mon Aug 16 2010 dimstar@opensuse.org
- Update to version 0.25.90:
  + Make vte parallel-buildable with gtk 2 and gtk 3
  + Bugs fixed:
  - bgo#617690: Setting default fg color should not cancel
    underline
  - bgo#614658: text selection with mouse is buggy when using
    the shift key
  - bgo#618749: set terminal widget background color to terminal
    background
  - bgo#601926: Don't hardcode meta to alt
  - bgo#618097: Broken backtab (cbt)
  - bgo#621298: Cursor invisible (plain black) in (xfce) Terminal
    & terminator
  - bgo#626676: Cleanup vte_terminal_determine_colors
  - bgo#620493: strict aliasing warning
  + Translation updates.
* Tue Jul 13 2010 dimstar@opensuse.org
- Update to version 0.25.1:
  + Add support for searching the buffer. New public API:
  - vte_terminal_search_[sg]et_regex
  - vte_terminal_search_find_(previous|next)
* Wed Jun 23 2010 dimstar@opensuse.org
- Update to version 0.24.2:
  + Fix reversed logic for saturation level of background.
  + Build fixes.
  + Updated translations.
* Thu Apr 29 2010 dimstar@opensuse.org
- Update to version 0.24.1:
  + bgo#613525: current git head does not build (undefined
    reference to XGetGeometry)
  + bgo#614469: Does no longer compile with -DX_DISPLAY_MISSING
  + bgo#615417: Reversed and one error saturation level in 0.24.0
- Drop vte-0.24.0-no-transparent-background-bnc594590.patch,
  merged a more complete patch.
* Tue Apr 13 2010 andrea@opensuse.org
- Add vte-0.24.0-no-transparent-background-bnc594590.patch to fix
  segfaults on programs using vte (lxterminal, gnome-terminal)
  with a transparent background. Fix bnc#594590.
* Mon Mar 29 2010 vuntz@opensuse.org
- Update to version 0.24.0:
  + Updated API docs
  + Cache backgrounds as cairo surfaces
  + Updated translations.
- Add libgladeui-1_0-devel BuildRequires and pass
  - -enable-glade-catalogue to configure to build the glade catalog.
- Use libexedir instead of prefix/lib.
* Thu Jan 14 2010 captain.magnus@opensuse.org
- Update to version 0.23.5:
  + Fix unintented soversion bump
- Changes from version 0.23.4:
  + Add public API vte_terminal_write_contents()
  + Update docs
* Thu Jan 14 2010 captain.magnus@opensuse.org
- Update to version 0.23.3:
  + Disable symbol deprecation stuff since they were broken
  + Merge pangocairo draw impl into vtedraw
  + bgo#534526 - Flickering when resizing a vte widget
  + bgo#605299 - Please support xterm bracketed paste mode
* Tue Dec 22 2009 vuntz@opensuse.org
- Update to version 0.23.2:
  + Fix overflow with unlimited scrollback lines
  + Require glib >= 2.22.0
  + Deprecate vte_terminal_get_padding
  + Add VteTerminal::inner-border style property
  + vteapp: Add --cursor-shape option
  + Bugs fixed:
  - bgo#604966 - Fix "select all" to include text occurring after
    the visible region
  - bgo#604135 - [PATCH] fix behaviour of set-scrolling-region
  - bgo#603733 - Remove deprecated Glib symbol
  - bgo#603713 - ibeam/underline cursor broken with large
    inner-border
  - bgo#471920 - Expose the border width property
  - bgo#601265 - gnome-terminal assert failure:
    table.c:723:_vte_table_match
  - revert fix for bgo#591648 - Don't clear the screen when
    switching to the alternate screen
* Sat Nov 14 2009 vuntz@opensuse.org
- Update to version 0.23.1:
  + Various crash and bug fixes
  + Rework mouse selection to be more robust.  In particular,
    PRIMARY selection now only changes when mouse button is
    released, not upon every motion when selecting.
  + Interpret and document negative number of scrollback lines as
    infinite
  + We now chain unhandled motion-notify events up such that the
    parent widget can give them a shot.
  + Bugs fixed:
  - bgo#597604 - assertion failed: (_vte_ring_contains (ring,
    position))
  - bgo#598124 - The selection does not only change when the
    mousebutton is released
  - bgo#598090 - LMB Mouse up event not registered when opining
    context popup menu
  - bgo#587463 - "select all"+copy from gnome-terminal includes
    lines no longer in scrollback
  - bgo#585370 - Incomplete disabling of python
  - bgo#597242 - libvte color and cursor glitches
  - bgo#591648 - Don't clear the screen when switching to the
    alternate screen
  - bgo#595445 - Motion notify events are not propagated to
    parent widget
  - bgo#569184 - vte generates unnecessary ioctl(I_FIND) kernel
    warnings
  - bgo#599444 - Scrollback index type mess
  - bgo#598814 - text.getText(0, -1) triggers assertion in
    vteaccess.c
  - bgo#596739 - Python bindings leak memory
  - bgo#597165 - void return in vte.c
  - bgo#587894 - the environment passing with python does no
    longer work
* Tue Sep 29 2009 dimstar@opensuse.org
- Update to version 0.22.2:
  + Fix crash introduced in previous release
  + Fix a11y assertion failure
  + Improve selection at the end of row
  + bgo#596444 - word-select includes \n when the word ends at the
    edge of the terminal
  + bgo#596460 - 0.22.1 kills vte based apps
  + lp#435646 - gnome-terminal assert failure.
* Mon Sep 28 2009 dimstar@opensuse.org
- Update to version 0.22.1:
  + bgo#596365 - libvte crashes when issueing 'reset' in a terminal
  + bgo#588033 - background tabs may lose lines off the bottom of
    the scrollback
  + bgo#596163 - Doesn't display expected background color in
    ncurses apps
  + bgo#596011 - Problem compiling vte 0.22.0 on Solaris
- Changes from previous versions:
  + Fix tab and wide-char handling
  + Another rewrite of the ring.  Stores ring data on tmp files on
    disk now.
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 0.21.5:
  + Finish ring rewrite.  Scrollback buffer consumes ten times less
    memory now, and better, doesn't allocate from the heap, so
    closing tabs actually releases memory.
* Fri Aug 28 2009 dimstar@opensuse.org
- Update to version 0.21.4:
  + Remove another stale assert()
  + Oops, use the right map decoding function is iso2022 code
- Changes from version 0.21.3:
  + Really fix the ring this time
  + Enable g_assert().  May trigger some bogus ones now
- Changes from version 0.21.2:
  + bgo#592990 - gnome terminal crashes with glibc detected.
* Tue Aug 25 2009 dimstar@opensuse.org
- Update to version 0.21.1:
  + Redesigning the vte buffer ring is going on.  Please report any
    misbehavior
  + Bugs fixed in this release:
  - bgo#590824 - gnome-terminal crashed with SIGSEGV after hiting
    ctrl+o
  - bgo#572230 - text mode program rendering is strange in cjk
    locale.
  - bgo#588200 - bashisms in shell scripts
* Wed Jun 10 2009 vuntz@novell.com
- Update to version 0.20.5:
  + Followup release to undo unintentded .soname bump.
* Tue Jun  2 2009 vuntz@novell.com
- Update to version 0.20.4:
  + New enum value VTE_ERASE_TTY.
  + Make VTE_ERASE_AUTO send \H for backspace if terminal erase is
    undefined.
  + bgo#584281 - build: avoid double installation of xterm
  + bgo#543379 - VTE sends NUL/^@ for backspace
* Wed May 27 2009 vuntz@novell.com
- Update to version 0.20.3:
  + bgo#583129 - [python] allow passing None as command or
    directory option
  + bgo#583078 - [python] allow passing of environment as a
    dictionary
* Tue May  5 2009 vuntz@novell.com
- Update to version 0.20.2:
  + bgo#567064 - Work around buggy iconv
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 0.20.1:
  + bgo#574491 – gnome-pty-helper can prevent volumes from being
    unmounted
  + bgo#576504 – vte does not pass its testsuite.
  + bgo#573674 – reset resets width to 80 chars
  + bgo#576797 – Double-click sometimes stops working
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Sun Mar 15 2009 vuntz@novell.com
- Update to version 0.20.0:
  + Support using a real bold font instead of pseudo-bolding
  + Respond to fontconfig configuration changes
  + Bugs fixed: bgo#54926, bgo#570208, bgo#548272, bgo#565688,
    bgo#566795, bgo#524170, bgo#566730, bgo#565679, bgo#565675,
    bgo#565663, bgo#575398, bgo#574616, bgo#574025
- Remove -fno-strict-aliasing from CFLAGS.
- Remove unneeded BuildRequires: gtk-doc, update-desktop-files
- Merge -doc into -devel as it only contained gtk-doc
* Fri Jan 23 2009 vuntz@novell.com
- Merge versions from GNOME:Factory:Next and openSUSE:Factory.
- Remove tests for openSUSE <= 10.2.
* Mon Jan 19 2009 crrodriguez@suse.de
- remove "la" files [BNC#357465]
* Sat Dec 20 2008 mboman@suse.de
- Update to version 0.19.4:
  + Support for correct rendering of combining characters
  + Fix background rendering.
  + Misc bug fixes.
  + bgo#564535 – check for gperf in autogen.sh
  + bgo#149631 – gnome-terminal doesn't combine combining chars in utf8
  + bgo#564057 – src/pty.c does not compile with
  - -disable-gnome-pty-helper
  + bgo#562695 - ship pkg-config file for python bindings
  + bgo#563752 – pangocairo backend recreates cairo_surface_t for
    background drawing
  + bgo#163213 – Cursor should remain visible when selected
* Sun Dec  7 2008 mboman@suse.de
- Update to version 0.19.3:
  + Really fix the rendering bug.
  + Bugs fixed: rh#474618, bgo#563274, bgo#563024, bgo#552096, bgo#559818,
    bgo#471480, bgo#110371, bgo#112172, bgo#560667, bgo#541441, bgo#562806,
    bgo#562511, bgo#540951, bgo#465036, bgo#127870, bgo#317236, bgo#107031,
    bgo#521420, bgo#514632, bgo#459553, bgo#562385, bgo#562332, bgo#562338,
    bgo#488960, bgo#561366, bgo#562187, bgo#416518, bgo#500191, bgo#514457,
    bgo#542561, bgo#560766, bgo#536894, bgo#561713, bgo#560819, bgo#560818,
    bgo#560977, bgo#561185, bgo#560817, bgo#560991, bgo#395599, bgo#557375,
    bgo#556398, bgo#339819, bgo#399364, bgo#556328, bgo#549835, bgo#509204,
    bgo#539130
  + Rewrote text selection.  Much less buggy now.  Specially block-mode.
  + Fixed rendering bug caused by wrong tab handling introduced in 0.19.0.
  + More deprecation.  VteReaper is deprecated and will be removed in 1.0.
  + Minor optimizations in the pangocairo backend.  Only one FcFontSort now
    instead of the previous two.
  + New, PangoCairo, rendering backend.  This is functionally equivalent to
    the previous default backend which was Xft.  And just a tad bit faster.
  + All other backends are removed.
  + Configurable cursor shape (block, underline, I-beam).
  + Preliminary object properties added to VteTerminal.
  + Vte now depends on glib, pango, gtk+, and nothing else.
  + API that will be removed in vte 1.0 has been marked deprecated in this
    release.
  + gnome-pty-helper does no longer depend on and link to glib
  + General code maintenance and cleanup.
  + Translation updates
* Tue Sep 23 2008 mboman@suse.de
- Update to version 0.17.4:
  + Translation updates
* Tue Sep  9 2008 maw@suse.de
- Update to version 0.17.3:
  + Update python bindings
  + Bug fixed: bgo#538344.
* Thu Aug 14 2008 mboman@novell.com
- Update to version 0.17.2:
  + Fix crasher on 64bit systems
  + Fix a bunch of warnings
  + Bug bgo#546940 â€“ Crash when selecting text
* Wed Aug  6 2008 maw@suse.de
- Update to version 0.17.1:
  + New API:
  * Make the cursor blinking follow the gtk setting by default,
    with a possible override
  * Set named cursors on matches
  * Do GRegex matching, to be used alternatively to the old
    vteregex matching
  * Add set-scroll-adjustments signal, needed to allow adding a
    VteTerminal into a GtkScrolledWindow
  * Add version check macro
  + Bugs fixed: bgo#546366, bgo#545924, bgo#542795, bgo#399744,
    bgo#510903, bgo#539130, bgo#540182, bgo#535552, bgo#535469,
    bgo#418918, bgo#535467, bgo#535468, and bgo#515972.
* Mon Jun 16 2008 maw@suse.de
- Update to version 0.16.14:
  + Bugs fixed:	bgo#536632, bgo#535022, bgo#534148, and bgo#516869.
* Thu May  1 2008 jpr@suse.de
- Remove vte-0.16.6-dont-disable-all-deprecateds.patch, the
  deprecation is handled in the configure stage now and is off by
  default.
* Fri Mar 14 2008 maw@suse.de
- Update to version 0.16.13:
  + Minor optimizations
  + Bugs fixed: bgo#517709 and bgo#449131.
* Fri Feb  1 2008 maw@suse.de
- Update to version 0.16.12:
  + More work around Gdk backends that don't issue
    GdkVisibilityNotify
  + Bugs fixed: bgo#503164 and bgo#449131.
* Wed Jan 30 2008 sbrabec@suse.cz
- Devhelp documentation moved to the separate package (bnc#248813).
* Tue Jan 29 2008 maw@suse.de
- Update to version 0.16.11:
  + Work around Gdk backends that don't issue GdkVisibilityNotify
  + Try transliteration when pasting text into a non-UTF-8 locale
  + Smart tab character: you can now copy/paste tab characters
    printed by cat, diff, and other line-oriented tools and get
    the tab character in the clipboard, instead of multiple
    spaces; the selection indicates that by being all or none
  + Bugs fixed: bnc#503164, bnc#319687, bnc#497246, bnc#412435,
    bnc#416561, bnc#416558, bnc#403217, bnc#118967, bnc#353610,
    bnc#499892, bnc#499891, bnc#499896, bnc#499893, bnc#499287,
    bnc#142640, bnc#439384, bnc#483642, and bnc#480735.
* Tue Sep 18 2007 sbrabec@suse.cz
- Updated to version 0.16.9:
  * Slightly improved pango backend
  * Fixed handling of wrapped links in gnome-terminal
  * Fixed troubles with pad
  * Handle Sun Cut, Copy, Paste keys
  * Fixed vteapp resize weirdness
  * Fixed spaces not underlined
  * Fixed vte crash on removing a terminal tab
  * Misc bug fixes
* Fri Aug 17 2007 maw@suse.de
- Add vte-0.16.8-bnc-300574.patch (#300574, b.g.o #450069).
* Mon Aug  6 2007 maw@suse.de
- Split off a -lang subpackage
- Use %%fdupes
- s#%%run_ldconfig#/sbin/ldconfig# in %%post and %%postun.
* Wed Aug  1 2007 mauro@suse.de 
- Update to version 0.16.8
- Fixed missing documentation in the tarball.
- Bugfixes for #337252, #448259, #449809, #450745.
* Fri Jul  6 2007 maw@suse.de
- Update to version 0.16.6
- Bugs fixed (against bugzilla.gnome.org): #431799, #429189,
  [#415044], #414716, #429278, #440475, #375112, #440377, #433776,
  [#445620], and #372743.
* Wed Apr 11 2007 maw@suse.de
- Update to version 0.16.1, which contains:
- Lots of bug fixes by Chris Wilson
- New feature: mouse scroll-wheel now feeds three arrow-up/down keys to the
  terminal if in the "alternate" mode.  The alternate mode is used by apps
  like vim, less, emacs, screen, etc.  This makes the scroll-wheel usable
  in a state that it was of no use before.
- Bugs fixed in this release:
  * Bug #426870 - vte often passes NUL to functions requiring valid unichar
  * Bug #419644 - Links do not get highlighted anymore
  * Bug #404757 - URL matching doesn't work with PCRE
  * Bug #426541 - crash on IRM escape code
  * Bug #424184 - Make scroll wheel send Page Up/Down when it makes sense
    Original patch by Shaun McCance and refined by Baris Cicek.
  * Bug #425767 - vte_terminal_set_color_highlight should test for
    NULL before _vte_debug_print
  * Bug #422385 - vte appears at the top of the root window even when
    packed at the bottom of it Patch by Dodji Seketeli.
  * Bug #420935 - glyph can be cropped with not fitting in a cell
  * Bug #420067 - Does not handle expose events whilst processing
    unseen incoming data
  * Bug #415381 - Improve performance of vte_terminal_insert_char()
  * Bug #418073 - Opacity ignored for vtexft
  * Bug #418910 - Asymmetric scrolling with mouse wheel
  * Bug #416634 - Rendering glitch as autowrapped chars are outside
    invalidated bbox
  * Bug #416635 - Rendering glitch: double draw of line below exposed region
  * Bug #418588 - Invalid read when drawing preedit cursor
  * Bug #417652 - Scrolling bug exposed by nvi
  * Bug #417301 - Terminal widgets don't respond to DPI changes
  (These bugs are viewable on bugzilla.gnome.org).
* Fri Mar 23 2007 maw@suse.de
- Update to version 0.16.0
- b.g.o fixes include: 412361, 411000, 410534, 410463, 159078,
  411276, 410534, 411276, 414716.
* Mon Feb 19 2007 maw@suse.de
- Update to version 0.15.3
- Update and rename vte-0.14.1.dif to
  vte-0.15.3-dont-disable-all-deprecateds.patch
- Remove vte-no-pwd.dif.
* Wed Feb  7 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552).
* Mon Jan 15 2007 sbrabec@suse.cz
- Fixed devel dependencies.
* Fri Dec  8 2006 maw@suse.de
- Move to /usr, and remove most hardcoded paths
- BuildRequire pkg-config
* Tue Nov 28 2006 sbrabec@suse.cz
- Build as user.
* Sat Oct 14 2006 danw@suse.de
- Remove dead patches
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 0.14.1
- Bug 358344 – autoscroll only works one way in fullscreen
- Bug 353756 – font setting cleanup
- Bug 356616 – libvte broken with new autotools
- Bug 354024 – Suppress multiple warnings for missing control sequence
  handlers
* Mon Sep 25 2006 jhargadon@suse.de
- added %%py_requires to the specfile for bug #207923
* Wed Sep  6 2006 anosek@suse.cz
- update to version 0.14.0
  o Minor doc syntax update.
  o Fix bug causing empty lines to not being copied.
  o Bug 350236 – Cannot copy text; invalid character sequence errors
  o Bug 352439 – URL highlighting seriously broken
  o Bug 351494 – Gnome-terminal doesn't kills bash on tab close
  o Bug 352365 – font caching problem for not-found glyphs
- fixed compiler warning: operation on 'tmp' may be undefined
  [#190917] (warning.patch)
* Wed Aug 30 2006 jhargadon@suse.de
- update to version 0.13.6
- Bug 351696 – crash on Terminal, check ->window before setting
  icon/window title
- Bug 350623 – Accessible text getTextAtOffset is broken
* Wed Aug 16 2006 jhargadon@suse.de
- update to version 0.13.5
- terminal backspace behavior not set to UTF-8 mode
- Bug 348814 – crash on Terminal
- Bug 336947 – [patch] Redundant vte_terminal_set_font_full() calls
- Bug 134800 – gnome-termnal hung up when input by ATOK
- Bug 339983 – gnome-pty-helper should log username
- Bug 121904 – copy-paste of empty line
- Bug 25290 – Small UI tweak to select-by-word
- Bug 311855 – Race in vte leads to blocking of input.
- Bug 339529 – gnome-terminal (vte) crashes when detatched window is
  closed
- Bug 331803 – style needs to be attached/detached to the window on
  realize/unrealize
- Bug 339448 – selection doesn't respect hard newlines
- Bug 160782 – Vte isn't multi-screen safe
- Bug 328850 – Crash when pasting selection
* Wed Aug 16 2006 cthiel@suse.de
- buildrequire python-gtk-devel instead of python-gtk
- don't buildrequire python-gobject2-devel
- fix requires on -devel package
* Wed Aug 16 2006 ro@suse.de
- added python-gobject2-devel to BuildRequires
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Jan 24 2006 jpr@suse.de
- Fix pkgconfig file Requires.private -> Requires
* Wed Jan 18 2006 sbrabec@suse.cz
- Updated to version 0.11.16.
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Tue Aug 23 2005 gekker@suse.de
- Update to version 0.11.15
* Thu Aug 11 2005 gekker@suse.de
- Update to version 0.11.14
* Wed Jun 22 2005 gekker@suse.de
- Update to version 0.11.13
* Wed Mar 16 2005 gekker@suse.de
- Remove .desktop file, it is just a test tool, not for menus
* Mon Mar  7 2005 gekker@suse.de
- add vte-memory-background.patch
* Thu Mar  3 2005 gekker@suse.de
- update to 0.11.12
* Tue Dec 21 2004 gekker@suse.de
- Update to version 0.11.11
- Rework patches so they apply
- Change spec file so it can find the libs
* Mon Nov 22 2004 ro@suse.de
- make specfile rpm3 compliant ...
  (non numeric if arguments need quoting)
* Fri Nov 19 2004 ro@suse.de
- removed extra aclocal include directive
* Tue Oct 19 2004 sbrabec@suse.cz
- Removed /opt/gnome/lib64/vte/gnome-pty-helper from permissions.
- Renamed no locale to nb.
* Tue Oct 19 2004 ro@suse.de
- use special permissions files to build on PLUS
* Tue Oct 12 2004 sbrabec@suse.cz
- Fixed libexecdir for bi-arch (#47050).
* Wed Sep 22 2004 hhetter@suse.de
- don't do pwd as command when nothing else was given
  (#45813)
* Wed May 19 2004 ro@suse.de
- do not define PANGO_DISABLE_DEPRECATED
* Tue Aug 19 2003 sbrabec@suse.cz
- Updated to version 0.11.10.
* Fri Aug 15 2003 adrian@suse.de
- install desktop file
* Wed Aug  6 2003 ro@suse.de
- don't define GTK_DISABLE_DEPRECATED since python-gtk includes
  still use/support some old features
* Thu Jul 24 2003 hhetter@suse.de
- really prefix to /opt/gnome
- move python stuff to /usr
- %%_lib fixes
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Wed Jun 25 2003 sbrabec@suse.cz
- Updated to version 0.10.29.
- Use %%find_lang.
* Fri Jun  6 2003 mmj@suse.de
- Add .la to -devel
* Fri Apr  4 2003 ro@suse.de
- use wildcard in filelist for python (should use macro)
* Wed Feb 26 2003 sbrabec@suse.cz
- Make gnome-pty-helper SGID tty, not utmp.
* Tue Feb 25 2003 sbrabec@suse.cz
- Fixed %%files and FHS fix (libexecdir).
* Fri Feb  7 2003 hhetter@suse.de
- updated to version 0.10.17 [GNOME 2.2.0]
* Tue Jan 21 2003 ro@suse.de
- lib64 fix
* Thu Jan 16 2003 hhetter@suse.de
- initial SuSE package
